==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/BitmapExport/ts/BitmapExport_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+88"/>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>Exportieren als Bitmap</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>Fehler beim Generieren der Bitmap Datei &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>Bitmap wurde erstellt als &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Bitmap file has been exported to &quot;%1&quot;</source>
        <translation type="obsolete">Bitmap wurde erstellt als &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>Bit&amp;map Export...</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>Bitmap Export</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>Grösse</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>Pixel pro Zeichnungseinheit:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation>Rand:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translation>Hintergrund</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>Weiss</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>Schwarz</translation>
    </message>
    <message>
        <source>Error while generating Bitmap file &quot;%1&quot;: %2</source>
        <translation type="obsolete">Fehler beim Generieren der Bitmap Datei &quot;%1&quot;: &quot;%2&quot;</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/BitmapExport/ts/BitmapExport_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+105"/>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>Exportieren als Bitmap</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translation>Fehler beim Generieren der Bitmap Datei &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translation>Bitmapdatei wurde erstellt als &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Bitmap file has been exported to &quot;%1&quot;</source>
        <translation type="obsolete">Bitmap wurde erstellt als &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>Bit&amp;map Export...</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>Bitmap Export</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>Grösse</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>Pixel pro Zeichnungseinheit:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation>Rand:</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translation>Hintergrund</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>Weiss</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>Schwarz</translation>
    </message>
    <message>
        <source>Error while generating Bitmap file &quot;%1&quot;: %2</source>
        <translation type="obsolete">Fehler beim Generieren der Bitmap Datei &quot;%1&quot;: &quot;%2&quot;</translation>
    </message>
</context>
</TS>
